Modify HIP_RETURN to print useful details

Change-Id: I23892c2d9a738b0298cdf24106d688a792937c73


[ROCm/hip commit: 2e8c1e9f24]
Αυτή η υποβολή περιλαμβάνεται σε:
Saleel Kudchadker
2020-06-05 10:45:28 -07:00
γονέας 81e6261ff8
υποβολή 75f05a8b01
4 αρχεία άλλαξαν με 29 προσθήκες και 23 διαγραφές
@@ -192,13 +192,13 @@ hipError_t ihipEventQuery(hipEvent_t event) {
hipError_t hipEventCreateWithFlags(hipEvent_t* event, unsigned flags) {
HIP_INIT_API(hipEventCreateWithFlags, event, flags);
HIP_RETURN(ihipEventCreateWithFlags(event, flags));
HIP_RETURN(ihipEventCreateWithFlags(event, flags), *event);
}
hipError_t hipEventCreate(hipEvent_t* event) {
HIP_INIT_API(hipEventCreate, event);
HIP_RETURN(ihipEventCreateWithFlags(event, 0));
HIP_RETURN(ihipEventCreateWithFlags(event, 0), *event);
}
hipError_t hipEventDestroy(hipEvent_t event) {
@@ -227,7 +227,7 @@ hipError_t hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop) {
hip::Event* eStart = reinterpret_cast<hip::Event*>(start);
hip::Event* eStop = reinterpret_cast<hip::Event*>(stop);
HIP_RETURN(eStart->elapsedTime(*eStop, *ms));
HIP_RETURN(eStart->elapsedTime(*eStop, *ms), "Elapsed Time = ", *ms);
}
hipError_t hipEventRecord(hipEvent_t event, hipStream_t stream) {